//---------------------------------------------
// Microchip 25AA1024 sample 
//
//  EEPROM   arduino pin No
// --------  --------------
// 1 CS       10
// 2 SO       12 MISO
// 3 WP       5V
// 4 GND      GND
// 5 SI       11 MOSI
// 6 SCK      13 SCK
// 7 HOLD     5V
// 8 VCC      5V
//--------------------------------------------
#define EEPROM_CS 10

#include <SPI.h>

void spi_eeprom_write( byte addrH, byte addrM, byte addrL, byte data )
{
  digitalWrite( EEPROM_CS, LOW );   // eeprom chip select enable 
  SPI.transfer( B00000010 );        // eeprom Write Instruction
  SPI.transfer( addrH );            // eeprom 24bit address 
  SPI.transfer( addrM );
  SPI.transfer( addrL );  
  SPI.transfer( data );  
  digitalWrite( EEPROM_CS, HIGH );  // eeprom chip select disable 
}

byte spi_eeprom_read( byte addrH, byte addrM, byte addrL )
{
  byte data;
  
  digitalWrite( EEPROM_CS, LOW );   // eeprom chip select enable 
  SPI.transfer( B00000011 );        // eeprom Read Instruction
  SPI.transfer( addrH );            // eeprom 24bit address 
  SPI.transfer( addrM );
  SPI.transfer( addrL );
  data = SPI.transfer(0);
  digitalWrite( EEPROM_CS, HIGH );  // eeprom chip select disable 

  return data;
}

void spi_eeprom_write_enable( void )
{
  digitalWrite( EEPROM_CS, LOW  );  // eeprom chip select enable 
  SPI.transfer( B00000110 );        // eeprom enable write operation Instruction
  digitalWrite( EEPROM_CS, HIGH );  // eeprom chip select disable   
}

void setup()
{
  pinMode(EEPROM_CS,  OUTPUT);
  pinMode(12,  INPUT);
  digitalWrite( EEPROM_CS, HIGH );  // eeprom chip select disable 
  SPI.begin();
  Serial.begin(9600);
}

void loop()
{
  byte i;
  byte j;
  
  for( i= 0 ; i < 10 ; i++ ) {
    spi_eeprom_write_enable();
    spi_eeprom_write( 0,0,i,i+20);
    delay(6);
  }
  for( i= 0 ; i < 10 ; i++ ) {
    j = spi_eeprom_read( 0,0,i);
    Serial.println( j, DEC);
  }
  while(true) {}
}
//--------------------------------- E N D ------------

